@@ -1,14 +1,13 @@
-#' @import utils
-#' 
+#' @importFrom utils globalVariables
 
-utils::globalVariables(c(".","k","Segment.Level","Segment.Child","Quant.Error",
+globalVariables(c(".","k","Segment.Level","Segment.Child","Quant.Error",
                          "noOfCellsBelowQuantizationError","noOfCells","index",
-                         "Segment.Parent","cluster","child","value",
+                         "Segment.Parent","cluster","child","value", "hvq_k","..count..",":=",
                          "min_dist", "perc", "Centroid_Type", "polygon_x", "polygon_y",
                          "quantError", "kout$cluster", 'kmedoids_model[["clustering"]]',
                          "cellID", "Mean_Absolute_Deviation", "Percentage_of_Anomalous_Points",
                          "hvt.results", "Index", "centroidRadius", "sumOriginal", "Quant.Error.x",
-                         "n.x", "n.y", "Quant.Error.y", "Scored.Quant.Error", "anomalyFlag",
+                         "n.x", "n.y", "Quant.Error.y", "Scored.Quant.Error", "anomalyFlag", "Row.No", "x_coord", "y_coord",
                          "bp.x", "bp.y", "x", "y", "density","Cell.ID","Cell.Number","MapA.Cell.ID","MapA.Segment.Child","MapA.Segment.Level"
                          ,"MapA.Segment.Parent","MapC.Cell.ID","MapC.Cell.Path","MapC.Segment.Child","MapC.Segment.Level","MapC.Segment.Parent",
-                         "Row.Number","identified_outlier_cells", "Cell.ID.x", "Cell.ID.y", "Layer1.Cell.ID", "Layer2.Cell.ID", "Segment.Child.x", "Segment.Child.y", "Segment.Level.x", "Segment.Level.y", "Segment.Parent.x", "Segment.Parent.y", "identified_Novelty_cells", "mapC_cell_path"))
\ No newline at end of file
+                         "Row.Number","identified_outlier_cells", "Cell.ID.x", "Cell.ID.y", "Layer1.Cell.ID", "Layer2.Cell.ID", "Segment.Child.x", "Segment.Child.y", "Segment.Level.x", "Segment.Level.y", "Segment.Parent.x", "Segment.Parent.y", "identified_Novelty_cells", "mapC_cell_path"))
